@@ -3,10 +3,10 @@
 // ------------------------------------------------------------ 
 Keyword = 
 [
-'CppAD  cppad-20160000.1: A Package for Differentiation of C++ Algorithms  ',' algorithmic automatic derivative version cppad.hpp syntax introduction example include file preprocessor symbols namespace ',
+'CppAD  cppad-20170000.0: A Package for Differentiation of C++ Algorithms  ',' algorithmic automatic derivative version cppad.hpp syntax introduction example include file preprocessor symbols namespace ',
 'Install  CppAD Download, Test, and Install Instructions  ',' step 1: 2: cmake 3: check 4: installation ',
-'download  Download The CppAD Source Code  ',' purpose distribution directory compressed archives current version release versions monthly unix file extraction windows testing install instructions subversion limitations stable ',
-'cmake  Using CMake to Configure CppAD  ',' makefile install prefix postfix include directories lib datadir documentation package compile flags profile maximum number threads sparsity internal structure vector sets memory usage tape implicit explicit the program command build directory cmake_verbose_makefile generator cppad_prefix cppad_postfix cmake_install_includedirs cmake_install_libdirs cmake_install_datadir cmake_install_docdir package_prefix cppad_cxx_flags c++11 cppad_profile_flag eigen fadbad cppad_testvector cppad_max_num_threads cppad_sparse_list cppad_tape_id_type cstdint cppad_tape_addr_type cppad_deprecated ',
+'download  Download The CppAD Source Code  ',' purpose distribution directory compressed archives current version subversion git release versions coin github monthly daily windows file extraction testing install instructions no documentation building ',
+'cmake  Using CMake to Configure CppAD  ',' makefile install prefix postfix include directories lib datadir documentation package compile flags profile maximum number threads sparsity internal structure vector sets memory usage tape implicit explicit the program command build directory check cmake_verbose_makefile generator cppad_prefix cppad_postfix cmake_install_includedirs cmake_install_libdirs cmake_install_datadir cmake_install_docdir package_prefix cppad_cxx_flags c++11 cppad_profile_flag eigen fadbad cppad_testvector cppad_max_num_threads cppad_tape_id_type cstdint cppad_tape_addr_type cppad_deprecated ',
 'adolc_prefix  Including the ADOL-C Examples and Tests  ',' get purpose speed unix cygwin get_adolc ',
 'get_adolc.sh  Download and Install Adolc in Build Directory  ',' syntax purpose requirements distribution external prefix reuse ',
 'colpack_prefix  Including the ColPack Sparsity Calculations  ',' get purpose cppad_lib example get_colpack ',
@@ -24,7 +24,7 @@ Keyword =
 'cppad_testvector  Choosing the CppAD Test Vector Template Class  ',' purpose std boost eigen ',
 'cmake_check  Checking the CppAD Examples and Tests  ',' purpose all windows subsets ',
 'pkgconfig  CppAD pkg-config Files  ',' pc purpose usage defined fields configuration ',
-'auto_tools  Auto Tools Unix Test and Installation  ',' speed profile prefix std vector boost eigen sparse internal sets implicit explicit compile flags openmp postfix adolc fadbad ipopt sacado memory usage tape deprecated 2012-12-26 distribution directory work configure make examples tests profiling cppad prefix_dir --with-documentation --with-testvector --with-sparse_option --with-deprecated max_num_threads cxx_flags openmp_flags postfix_dir adolc_dir linux cygwin boost_dir eigen_dir fadbad_dir ipopt_dir sacado_dir tape_addr_type tape_id_type ',
+'auto_tools  Auto Tools Unix Test and Installation  ',' speed profile prefix std vector boost eigen sparse internal sets implicit explicit compile flags openmp postfix adolc fadbad ipopt sacado memory usage tape deprecated 2012-12-26 distribution directory work configure make examples tests profiling cppad prefix_dir --with-documentation --with-testvector --with-deprecated max_num_threads cxx_flags openmp_flags postfix_dir adolc_dir linux cygwin boost_dir eigen_dir fadbad_dir ipopt_dir sacado_dir tape_addr_type tape_id_type ',
 'Introduction  An Introduction by Example to Algorithmic Differentiation  ',' ad automatic purpose preface forward mode reverse operation count efficiency outline reference ',
 'get_started.cpp  Getting Started Using CppAD to Compute Derivatives  ',' simple example purpose function value poly exercises program output running ',
 'exp_2  Second Order Exponential Approximation  ',' example algorithm syntax purpose mathematical form include type implementation test exercises ',
@@ -71,7 +71,7 @@ Keyword =
 'ad_output  AD Output Stream Operator  ',' << syntax purpose assumption result operation sequence example ',
 'ad_input.cpp  AD Output Operator: Example and Test  ',' << ',
 'ad_output.cpp  AD Output Operator: Example and Test  ',' << ',
-'PrintFor  Printing AD Values During Forward Mode  ',' text output debug syntax purpose f.forward(0 x) before var after discussion alternative example ',
+'PrintFor  Printing AD Values During Forward Mode  ',' text output debug syntax purpose f.forward(0 x) before var after redirecting discussion alternative example ',
 'print_for_cout.cpp  Printing During Forward Mode: Example and Test  ',' running source code output ',
 'print_for_string.cpp  Print During Zero Order Forward Mode: Example and Test  ',' ',
 'Var2Par  Convert an AD Variable to a Parameter  ',' from value_ obtain during taping syntax see also purpose example ',
@@ -143,7 +143,7 @@ Keyword =
 'azmul  Absolute Zero Multiplication  ',' syntax purpose base ad<base> vecad<base> example ',
 'azmul.cpp  AD Absolute Zero Multiplication: Example and Test  ',' ',
 'CondExp  AD Conditional Expressions  ',' assign syntax purpose rel type left right if_true if_false result optimize deprecate 2005-08-07 operation sequence example test atan2 ',
-'cond_exp.cpp  Conditional Expressions: Example and Test  ',' condexp description ',
+'cond_exp.cpp  Conditional Expressions: Example and Test  ',' see also description ',
 'Discrete  Discrete AD Functions  ',' cppad_discrete_function syntax purpose base name ay create version operation sequence derivatives parallel mode example cppadcreatediscrete deprecated 2007-07-28 ',
 'tape_index.cpp  Taping Array Index Operation: Example and Test  ',' ',
 'interp_onetape.cpp  Interpolation With Out Retaping: Example and Test  ',' interpolate retape see also ',
@@ -151,26 +151,42 @@ Keyword =
 'numeric_limits  Numeric Limits For an AD and Base Types  ',' syntax cppad::numeric_limits std::numeric_limits float epsilon min max quiet_nan example ',
 'num_limits.cpp  Numeric Limits: Example and Test  ',' ',
 'atomic  Atomic AD Functions  ',' operation ',
-'checkpoint  Checkpointing Functions  ',' syntax purpose reduce memory faster recording method constructor base advector name ay sparsity size_var option algo atom_fun clear restriction example ',
+'checkpoint  Checkpointing Functions  ',' syntax see also purpose reduce memory faster recording repeating forward restriction multiple level ad method constructor base advector name ay sparsity optimize size_var option algo atom_fun clear example ',
 'checkpoint.cpp  Simple Checkpointing: Example and Test  ',' purpose ',
+'atomic_mul_level.cpp  Atomic Operations and Multiple-Levels of AD: Example and Test  ',' discussion ',
+'checkpoint_ode.cpp  Checkpointing an ODE Solver: Example and Test  ',' see also purpose problem solution ',
+'checkpoint_extended_ode.cpp  Checkpointing an Extended ODE Solver: Example and Test  ',' mul_level see also discussion problem solution ',
 'atomic_base  User Defined Atomic AD Functions  ',' syntax purpose virtual examples getting started scalar vector range hessian sparsity patterns general case ',
-'atomic_ctor  Atomic Function Constructor  ',' syntax atomic_user ctor_arg_list afun implementation atomic_base restrictions name sparsity examples define ',
+'atomic_ctor  Atomic Function Constructor  ',' syntax atomic_user ctor_arg_list afun implementation atomic_base restrictions name sparsity example define ',
 'atomic_option  Set Atomic Function Options  ',' syntax atomic_sparsity pack_sparsity_enum bool_sparsity_enum set_sparsity_enum ',
 'atomic_afun  Using AD Version of Atomic Function  ',' syntax purpose advector ay examples ',
-'atomic_forward  Atomic Forward Mode  ',' callback virtual syntax purpose implementation q vx vy tx ty ok discussion examples define use ',
-'atomic_reverse  Atomic Reverse Mode  ',' syntax purpose implementation q tx ty f g h py px ok examples define use ',
-'atomic_for_sparse_jac  Atomic Forward Jacobian Sparsity Patterns  ',' syntax purpose implementation q ok examples define use ',
-'atomic_rev_sparse_jac  Atomic Reverse Jacobian Sparsity Patterns  ',' syntax purpose implementation q rt st ok examples define use ',
-'atomic_rev_sparse_hes  Atomic Reverse Hessian Sparsity Patterns  ',' syntax purpose implementation vx q examples define use ',
+'atomic_forward  Atomic Forward Mode  ',' callback virtual syntax purpose implementation q vx vy tx ty ok discussion examples ',
+'atomic_reverse  Atomic Reverse Mode  ',' syntax purpose implementation q tx ty f g h py px ok examples ',
+'atomic_for_sparse_jac  Atomic Forward Jacobian Sparsity Patterns  ',' syntax deprecated 2016-06-27 purpose implementation q ok examples ',
+'atomic_rev_sparse_jac  Atomic Reverse Jacobian Sparsity Patterns  ',' syntax deprecated 2016-06-27 purpose implementation q rt st ok examples ',
+'atomic_for_sparse_hes  Atomic Forward Hessian Sparsity Patterns  ',' syntax deprecated 2016-06-27 purpose implementation vx examples ',
+'atomic_rev_sparse_hes  Atomic Reverse Hessian Sparsity Patterns  ',' syntax deprecated 2016-06-27 purpose implementation vx q examples ',
 'atomic_base_clear  Free Static Variables  ',' syntax purpose future use restriction ',
+'atomic_forward.cpp  Atomic Forward: Example and Test  ',' purpose function start class definition constructor use ',
+'atomic_reverse.cpp  Atomic Reverse: Example and Test  ',' purpose function start class definition constructor forward use ',
+'atomic_for_sparse_jac.cpp  Atomic Forward Jacobian Sparsity: Example and Test  ',' purpose function start class definition constructor use with x_1 both variable parameter ',
+'atomic_rev_sparse_jac.cpp  Atomic Reverse Jacobian Sparsity: Example and Test  ',' purpose function start class definition constructor forward use with x_1 both variable parameter ',
+'atomic_for_sparse_hes.cpp  Atomic Forward Hessian Sparsity: Example and Test  ',' purpose function start class definition constructor for_sparse_jac rev_sparse_jac use with x_1 both variable parameter ',
+'atomic_rev_sparse_hes.cpp  Atomic Reverse Hessian Sparsity: Example and Test  ',' purpose function start class definition constructor forward for_sparse_jac rev_sparse_jac use with x_1 both variable parameter ',
 'atomic_get_started.cpp  Getting Started with Atomic Operations: Example and Test  ',' purpose class definition constructor forward end use function recording ',
 'atomic_norm_sq.cpp  Atomic Euclidean Norm Squared: Example and Test  ',' bool_sparsity_enum theory start class definition constructor forward reverse for_sparse_jac rev_sparse_jac rev_sparse_hes end use function recording ',
 'atomic_reciprocal.cpp  Reciprocal as an Atomic Operation: Example and Test  ',' set_sparsity_enum theory start class definition constructor forward reverse for_sparse_jac rev_sparse_jac rev_sparse_hes end use function recording ',
-'atomic_sparsity.cpp  Atomic Sparsity Patterns: Example and Test  ',' function pack_sparsity_enum start class definition constructor forward for_sparse_jac rev_sparse_jac rev_sparse_hes end use recording forsparse_jac ',
+'atomic_set_sparsity.cpp  Atomic Sparsity with Set Patterns: Example and Test  ',' function set_sparsity_enum start class definition constructor forward for_sparse_jac rev_sparse_jac for_sparse_hes rev_sparse_hes end recording result ',
 'atomic_tangent.cpp  Tan and Tanh as User Atomic Operations: Example and Test  ',' theory sparsity start class definition constructor forward reverse for_sparse_jac rev_sparse_jac rev_sparse_hes end function recording large values ',
-'atomic_hes_sparse.cpp  Atomic Operation Hessian Sparsity: Example and Test  ',' purpose start class definition constructor forward for_sparse_jac rev_sparse_hes use function with x_1 both variable parameter ',
-'atomic_mat_mul.cpp  User Atomic Matrix Multiply: Example and Test  ',' class definition function constructor recording forward reverse option for_sparse_jac rev_sparse_jac rev_sparse_hes ',
-'atomic_matrix_mul.hpp  Matrix Multiply as an Atomic Operation  ',' start class definition constructor left operand element index right result forward multipliy reverse for_sparse_jac rev_sparse_jac rev_sparse_hes end ',
+'atomic_eigen_mat_mul.cpp  Atomic Eigen Matrix Multiply: Example and Test  ',' description class definition use function constructor ',
+'atomic_eigen_mat_mul.hpp  Atomic Eigen Matrix Multiply Class  ',' see also purpose dimensions theory forward product two matrices reverse start definition public types constructor op private variables for_sparse_jac rev_sparse_jac for_sparse_hes rev_sparse_hes end ',
+'atomic_eigen_mat_inv.cpp  Atomic Eigen Matrix Inverse: Example and Test  ',' description class definition use function constructor ',
+'atomic_eigen_mat_inv.hpp  Atomic Eigen Matrix Inversion Class  ',' purpose dimensions theory forward product three matrices reverse start definition public types constructor op private variables end ',
+'atomic_eigen_cholesky.cpp  Atomic Eigen Cholesky Factorization: Example and Test  ',' description use function constructor ',
+'cholesky_theory  AD Theory for Cholesky Factorization  ',' reference notation taylor coefficient lower triangular part forward mode lemma 1 proof 2 reverse case = 0 > ',
+'atomic_eigen_cholesky.hpp  Atomic Eigen Cholesky Factorization Class  ',' purpose start definition public types constructor op private variables forward reverse end ',
+'atomic_mat_mul.cpp  User Atomic Matrix Multiply: Example and Test  ',' see also class definition function constructor recording forward reverse option for_sparse_jac rev_sparse_jac rev_sparse_hes ',
+'atomic_mat_mul.hpp  Matrix Multiply as an Atomic Operation  ',' see also dimensions start class definition constructor left operand element index right result forward reverse for_sparse_jac rev_sparse_jac rev_sparse_hes end ',
 'BoolValued  Bool Valued Operations and Functions with AD Arguments  ',' ',
 'Compare  AD Binary Comparison Operators  ',' < <= > >= == != syntax purpose operation sequence assumptions example ',
 'compare.cpp  AD Binary Comparison Operators: Example and Test  ',' < <= > >= == != ',
@@ -192,10 +208,11 @@ Keyword =
 'base_std_math  Base Type Requirements for Standard Math Functions  ',' purpose unary cppad_standard_math_unary erf asinh acosh atanh expm1 log1p sign pow isnan ',
 'base_limits  Base Type Requirements for Numeric Limits  ',' cppad::numeric_limits cppad_numeric_limits ',
 'base_to_string  Extending to_string To Another Floating Point Type  ',' requirement cppad_to_string ',
+'base_hash  Base Type Requirements for Hash Coding Values  ',' syntax purpose default code inline example ',
 'base_example  Example AD Base Types That are not AD<OtherBase>  ',' ',
-'base_alloc.hpp  Example AD<Base> Where Base Constructor Allocates Memory  ',' purpose include file computed assignment macro binary operator boolean class definition condexpop condexprel equalopseq identical output integer azmul ordered unary standard math erf asinh acosh atanh expm1 log1p pow numeric_limits ',
+'base_alloc.hpp  Example AD<Base> Where Base Constructor Allocates Memory  ',' purpose include file computed assignment macro binary operator boolean class definition condexpop condexprel equalopseq identical output integer azmul ordered unary standard math erf asinh acosh atanh expm1 log1p pow numeric_limits to_string hash_code ',
 'base_require.cpp  Using a User Defined AD Base Type: Example and Test  ',' purpose ',
-'base_adolc.hpp  Enable use of AD<Base> where Base is Adolc\'s adouble Type  ',' syntax example include files condexpop condexprel equalopseq identical integer azmul ordered unary standard math erf asinh acosh atanh expm1 log1p sign abs pow numeric_limits ',
+'base_adolc.hpp  Enable use of AD<Base> where Base is Adolc\'s adouble Type  ',' syntax example include files condexpop condexprel equalopseq identical integer azmul ordered unary standard math erf asinh acosh atanh expm1 log1p sign abs pow numeric_limits to_string hash_code ',
 'mul_level_adolc.cpp  Using Adolc with Multiple Levels of Taping: Example and Test  ',' purpose memory management configuration requirement source ',
 'base_float.hpp  Enable use of AD<Base> where Base is float  ',' condexpop condexprel equalopseq identical integer azmul ordered unary standard math sign pow numeric_limits to_string ',
 'base_double.hpp  Enable use of AD<Base> where Base is double  ',' condexpop condexprel equalopseq identical integer azmul ordered unary standard math sign pow numeric_limits to_string ',
@@ -219,7 +236,7 @@ Keyword =
 'forward_order  Multiple Order Forward Mode  ',' any syntax purpose function values derivative notation one q xq orders restrictions x(t) y(t) yq vector zero first second example ',
 'forward.cpp  Forward Mode: Example and Test  ',' ',
 'forward_order.cpp  Forward Mode: Example and Test of Multiple Orders  ',' ',
-'forward_dir  Multiple Directions Forward Mode  ',' syntax purpose notation q xq zero order non-zero lower orders x(t) y(t) yq vector example ',
+'forward_dir  Multiple Directions Forward Mode  ',' syntax purpose reverse notation q xq zero order non-zero lower orders x(t) y(t) yq vector example ',
 'forward_dir.cpp  Forward Mode: Example and Test of Multiple Directions  ',' orders ',
 'size_order  Number Taylor Coefficient Orders Currently Stored  ',' syntax see also purpose constructor forward capacity_order example ',
 'compare_change  Comparison Changes Between Taping and Zero Order Forward  ',' adfun syntax purpose count speed number discussion op_index example ',
@@ -236,7 +253,7 @@ Keyword =
 'hes_times_dir.cpp  Hessian Times Direction: Example and Test  ',' ',
 'reverse_any  Any Order Reverse Mode  ',' derivative syntax purpose notation u^(k) x(t u) y(t w^(k) w(u) f q dw first second vector example ',
 'reverse_three.cpp  Third Order Reverse Mode: Example and Test  ',' taylor coefficients ',
-'reverse_any.cpp  Reverse Mode General Case: Example and Test  ',' purpose processing steps ',
+'reverse_checkpoint.cpp  Reverse Mode General Case (Checkpointing): Example and Test  ',' see also purpose processing steps ',
 'Sparse  Calculating Sparsity Patterns  ',' ',
 'ForSparseJac  Jacobian Sparsity Pattern: Forward Mode  ',' syntax purpose size_forward_bool size_forward_set q transpose dependency false true vectorset entire example ',
 'for_sparse_jac.cpp  Forward Mode Jacobian Sparsity: Example and Test  ',' forsparsejac ',
@@ -246,6 +263,8 @@ Keyword =
 'RevSparseHes  Hessian Sparsity Pattern: Reverse Mode  ',' syntax purpose f q transpose false true vectorset entire example ',
 'rev_sparse_hes.cpp  Reverse Mode Hessian Sparsity: Example and Test  ',' revsparsehes ',
 'sparsity_sub.cpp  Sparsity Patterns For a Subset of Variables: Example and Test  ',' see also forsparsejac revsparsehes ',
+'ForSparseHes  Hessian Sparsity Pattern: Forward Mode  ',' syntax purpose vectorset algorithm example ',
+'for_sparse_hes.cpp  Forward Mode Hessian Sparsity: Example and Test  ',' forsparsehes ',
 'bool_sparsity.cpp  Using vectorBool Sparsity To Conserve Memory: Example and Test  ',' purpose ',
 'Drivers  First and Second Derivatives: Easy Drivers  ',' forward reverse ',
 'Jacobian  Jacobian: Driver Routine  ',' first derivative syntax purpose vector forward reverse example ',
@@ -263,14 +282,20 @@ Keyword =
 'rev_two.cpp  Second Partials Reverse Driver: Example and Test  ',' ',
 'sparse_jacobian  Sparse Jacobian: Easy Driver  ',' sparsejacobian syntax purpose f row col work color_method n_sweep vectorbase vectorset restrictions vectorsize uses forward example ',
 'sparse_jacobian.cpp  Sparse Jacobian: Example and Test  ',' spare ',
-'sparse_hessian  Sparse Hessian: Easy Driver  ',' sparsehessian syntax purpose f w row col work color_method n_sweep vectorbase vectorset restrictions vectorsize uses forward example subset ',
+'sparse_hessian  Sparse Hessian: Easy Driver  ',' sparsehessian syntax purpose f w work column subset row color_method n_sweep vectorbase vectorset restrictions vectorsize uses forward example ',
 'sparse_hessian.cpp  Sparse Hessian: Example and Test  ',' spare ',
 'sub_sparse_hes.cpp  Computing Sparse Hessian for a Subset of Variables  ',' purpose see also function example ',
 'sparse_sub_hes.cpp  Sparse Hessian on Subset of Variables: Example and Test  ',' purpose see also ',
 'FunCheck  Check an ADFun Sequence of Operations  ',' syntax purpose g ok vector uses forward discussion example ',
 'fun_check.cpp  ADFun Check and Re-Tape: Example and Test  ',' funcheck dependent ',
-'optimize  Optimize an ADFun Object Tape  ',' sequence operations speed memory ndebug syntax purpose improvements testing efficiency atomic functions rev_sparse_jac nan checking optimization example ',
-'optimize.cpp  ADFun Operation Sequence Optimization: Example and Test  ',' ',
+'optimize  Optimize an ADFun Object Tape  ',' sequence operations speed memory ndebug syntax purpose options no_conditional_skip no_compare_op no_print_for_op examples efficiency testing atomic functions rev_sparse_jac nan checking optimization ',
+'optimize_forward_active.cpp  Example Optimization and Forward Activity Analysis  ',' ',
+'optimize_reverse_active.cpp  Example Optimization and Reverse Activity Analysis  ',' ',
+'optimize_compare_op.cpp  Example Optimization and Comparison Operators  ',' see also ',
+'optimize_print_for.cpp  Example Optimization and Print Forward Operators  ',' ',
+'optimize_conditional_skip.cpp  Example Optimization and Conditional Expressions  ',' see also ',
+'optimize_nest_conditional.cpp  Example Optimization and Nested Conditional Expressions  ',' see also ',
+'optimize_cumulative_sum.cpp  Example Optimization and Cumulative Sum Operations  ',' ',
 'check_for_nan  Check an ADFun Object For Nan Results  ',' syntax debugging default error message vector_size file_name index get_check_for_nan example ',
 'check_for_nan.cpp  ADFun Checking For Nan: Example and Test  ',' ',
 'preprocessor  CppAD API Preprocessor Symbols  ',' cppad_ null pointer purpose documented here cppad_null cppad_package_string cppad_use_cplusplus_2011 elsewhere deprecated ',
@@ -294,7 +319,7 @@ Keyword =
 'team_openmp.cpp  OpenMP Implementation of a Team of AD Threads  ',' ',
 'team_bthread.cpp  Boost Thread Implementation of a Team of AD Threads  ',' ',
 'team_pthread.cpp  Pthread Implementation of a Team of AD Threads  ',' pthread_exit bug cygwin ',
-'utility  Some General Purpose Utilities  ',' testing c++ concepts numerical routines miscellaneous error handler simple vector template class multi-threading memory allocation sorting indices to_string ',
+'utility  Some General Purpose Utilities  ',' testing c++ concepts numerical routines miscellaneous error handler simple vector template class multi-threading memory allocation sorting indices to_string set_union ',
 'ErrorHandler  Replacing the CppAD Error Handler  ',' replace assert exception syntax constructor parallel mode call info known line file exp msg example ',
 'error_handler.cpp  Replacing The CppAD Error Handler: Example and Test  ',' ',
 'cppad_assert  CppAD Assertions During Execution  ',' macro cppad_assert_known cppad_assert_unknown syntax purpose ndebug restriction exp msg error handler ',
@@ -371,6 +396,8 @@ Keyword =
 'index_sort.cpp  Index Sort: Example and Test  ',' ',
 'to_string  Convert Certain Types to a String  ',' syntax see also purpose value integer float example ',
 'to_string.cpp  to_string: Example and Test  ',' ',
+'set_union  Union of Standard Sets  ',' syntax purpose element left right result example ',
+'set_union.cpp  Set Union: Example and Test  ',' ',
 'ipopt_solve  Use Ipopt to Solve a Nonlinear Programming Problem  ',' syntax purpose include file bvector dvector options retape sparse string numeric integer xi xl xu gl gu fg_eval advector solution status zl zu lambda obj_value example get_started ode_inverse ',
 'ipopt_solve_get_started.cpp  Nonlinear Programming Using CppAD and Ipopt: Example and Test  ',' purpose configuration requirement ',
 'ipopt_solve_retape.cpp  Nonlinear Programming Retaping: Example and Test  ',' purpose ',
@@ -405,7 +432,7 @@ Keyword =
 'lu_vec_ad_ok.cpp  Lu Factor and Solve With Recorded Pivoting: Example and Test  ',' ',
 'testvector  Using The CppAD Test Vector Template Class  ',' cppad_testvector syntax introduction cppad::vector std::vector boost::numeric::ublas::vector eigen vectors ',
 'speed  Speed Test an Operator Overloading AD Package  ',' purpose ',
-'speed_main  Running the Speed Test Program  ',' cppad uniform_01 syntax purpose package double profile correct seed option_list onetape optimize atomic memory sparsity options boolsparsity colpack correctness results n_sweep link functions ',
+'speed_main  Running the Speed Test Program  ',' cppad uniform_01 syntax purpose package double profile correct seed global options onetape optimize atomic memory sparsity boolsparsity revsparsity colpack correctness results n_sweep link functions ',
 'link_det_lu  Speed Testing Gradient of Determinant Using Lu Factorization  ',' prototype purpose method return value size repeat matrix double ',
 'link_det_minor  Speed Testing Gradient of Determinant by Minor Expansion  ',' prototype purpose method return value size repeat matrix double ',
 'link_mat_mul  Speed Testing Derivative of Matrix Multiply  ',' multiple prototype purpose return value repeat z dz ',
@@ -509,9 +536,10 @@ Keyword =
 'reverse_identity  An Important Reverse Mode Identity  ',' notation sweep theorem proof ',
 'glossary  Glossary  ',' efficient ad function base type above elementary vector operation atomic sequence dependent independent parameter sparsity pattern boolean sets tape active inactive variable variables taylor coefficient ',
 'Bib  Bibliography  ',' abramowitz stegun the c++ programming language evaluating derivatives numerical recipes shampine l.f. ',
-'wish_list  The CppAD Wish List  ',' base requirements printfor optimization checkpoint machine epsilon examples adolc optimizing nested conditional expressions forward mode recomputation iterator interface compilation speed operation sequence comparison changes software guidelines tracing atan2 benderquad ',
+'wish_list  The CppAD Wish List  ',' optimization taping special operators checkpoint retape testing sparsity patterns check_finite compilation speed base requirements adolc forward mode recomputation iterator interface operation sequence software guidelines tracing atan2 benderquad ',
 'whats_new  Changes and Additions to CppAD  ',' introduction this year previous years ',
-'whats_new_15  CppAD Changes and Additions During 2015  ',' introduction 12-29 12-28 12-08 12-01 11-30 11-25 11-24 11-14 11-08 11-06 10-21 10-16 10-06 10-04 10-03 10-02 09-28 09-27 09-25 09-24 09-23 09-21 09-20 09-19 09-16 09-03 09-02 08-31 08-30 08-29 08-28 08-26 08-25 08-20 08-17 08-16 08-09 08-06 07-31 06-16 06-11 06-09 06-07 05-26 cond_exp_1 cond_exp_2 05-11 05-10 05-09 05-08 05-07 05-05 04-18 03-13 03-06 02-28 02-18 02-16 02-14 02-11 02-10 02-09 02-07 02-06 02-04 02-03 02-02 01-30 01-29 01-26 01-23 01-21 01-20 01-09 01-07 01-02 ',
+'whats_new_16  Changes and Additions to CppAD During 2016  ',' introduction 12-23 12-20 12-18 12-13 12-11 12-09 11-18 11-14 11-13 10-27 10-12 09-29 09-27 09-26 09-16 09-13 08-30 08-25 07-17 07-14 06-30 06-29 06-27 06-25 06-10 05-05 04-17 03-27 03-26 03-25 03-24 03-23 03-22 03-21 03-20 03-19 03-17 03-12 03-05 03-01 02-29 02-28 02-27 02-26 02-25 02-23 01-21 01-20 01-18 ',
+'whats_new_15  CppAD Changes and Additions During 2015  ',' introduction 12-31 12-29 12-28 12-08 12-01 11-30 11-25 11-24 11-14 11-08 11-06 10-21 10-16 10-06 10-04 10-03 10-02 09-28 09-27 09-25 09-24 09-23 09-21 09-20 09-19 09-16 09-03 09-02 08-31 08-30 08-29 08-28 08-26 08-25 08-20 08-17 08-16 08-09 08-06 07-31 06-16 06-11 06-09 06-07 05-26 cond_exp_1 cond_exp_2 05-11 05-10 05-09 05-08 05-07 05-05 04-18 03-13 03-06 02-28 02-18 02-16 02-14 02-11 02-10 02-09 02-07 02-06 02-04 02-03 02-02 01-30 01-29 01-26 01-23 01-21 01-20 01-09 01-07 01-02 ',
 'whats_new_14  CppAD Changes and Additions During 2014  ',' introduction 12-30 12-29 12-28 12-27 12-26 12-25 12-23 12-22 12-17 12-16 12-15 11-28 11-27 09-28 09-27 09-25 09-21 05-28 05-27 05-23 05-22 05-20 05-19 05-16 05-14 03-18 03-17 03-09 03-05 03-02 03-01 02-28 02-27 02-26 02-23 02-22 02-17 02-15 01-26 01-21 01-10 ',
 'whats_new_13  CppAD Changes and Additions During 2013  ',' introduction 12-29 12-27 12-26 12-24 11-27 11-13 11-12 10-29 10-23 10-22 10-16 10-15 10-14 10-13 10-12 09-20 09-19 09-18 09-07 08-12 08-11 08-06 07-26 05-28 05-21 05-17 05-15 05-14 05-12 05-11 05-04 04-28 04-27 04-26 ',
 'whats_new_12  CppAD Changes and Additions During 2012  ',' introduction 12-30 12-29 12-28 12-27 12-26 12-23 12-22 12-20 12-19 12-17 12-15 12-14 12-13 11-28 11-21 11-20 11-17 11-16 11-14 11-09 11-06 11-04 10-31 10-30 10-25 10-24 10-12 10-04 10-03 10-02 09-24 09-11 08-05 07-30 07-08 07-07 07-05 07-04 07-03 07-02 07-01 06-17 06-16 06-15 06-12 06-10 06-09 06-08 06-07 06-05 06-04 06-03 06-02 06-01 05-31 05-30 05-29 05-27 05-24 04-19 04-18 04-17 04-10 04-06 04-05 04-01 03-27 03-26 03-23 03-21 03-17 03-11 03-03 03-02 02-11 02-10 02-09 01-30 01-27 01-24 01-23 01-20 01-19 01-16 01-15 01-12 01-07 01-02 ',
@@ -524,7 +552,7 @@ Keyword =
 'whats_new_05  Changes and Additions to CppAD During 2005  ',' 12-24 12-23 12-22 12-20 12-19 12-16 12-15 12-14 12-11 12-08 12-07 12-06 12-05 12-03 12-02 12-01 11-23 11-22 11-20 11-19 11-15 11-12 11-09 11-07 11-06 11-01 10-20 10-18 10-14 10-12 10-06 09-29 09-27 09-24 09-20 09-14 09-09 09-07 08-30 08-24 08-20 08-19 08-15 08-14 08-13 08-07 07-21 07-19 07-15 07-11 07-08 07-05 07-04 07-03 07-02 07-01 06-25 06-24 06-18 06-14 06-13 06-06 05-19 05-18 05-16 05-12 05-06 05-01 04-21 04-20 04-19 03-26 03-23 03-22 03-09 03-04 03-01 02-24 01-08 ',
 'whats_new_04  Changes and Additions to CppAD During 2004  ',' introduction 12-11 12-09 12-03 11-17 11-16 11-15 11-14 11-13 11-12 11-10 11-04 11-02 11-01 10-29 10-28 10-27 10-21 10-19 10-16 10-06 09-29 09-26 09-23 09-21 09-13 09-10 09-09 09-07 09-04 09-02 08-27 08-25 08-24 08-12 07-31 07-08 07-07 07-03 07-02 06-29 06-25 06-12 06-04 06-03 06-01 05-30 05-29 05-26 05-25 05-14 05-12 05-09 05-07 05-04 05-03 04-29 04-28 04-25 04-24 04-22 04-21 04-20 04-19 04-09 04-08 04-07 04-03 04-02 04-01 03-30 03-28 03-25 03-18 03-17 03-15 03-12 03-11 03-09 03-07 03-06 03-05 03-04 03-03 03-01 02-29 02-28 02-21 02-20 02-17 02-16 02-15 02-12 02-01 01-29 01-28 01-22 ',
 'whats_new_03  Changes and Additions to CppAD During 2003  ',' introduction 12-24 12-22 12-14 12-13 12-12 12-10 12-05 12-01 11-21 11-20 11-16 11-15 11-14 11-12 11-11 11-06 11-04 11-02 10-21 10-16 10-14 10-10 10-06 10-05 09-30 09-20 09-19 09-18 09-15 09-14 09-13 09-06 09-05 09-04 09-03 08-23 08-22 08-19 08-17 08-16 08-11 08-10 08-07 08-06 08-05 08-04 08-03 08-01 07-30 07-29 07-26 07-22 07-20 07-18 07-16 07-14 ',
-'deprecated  CppAD Deprecated API Features  ',' ',
+'deprecated  CppAD Deprecated API Features  ',' atomic functions ',
 'include_deprecated  Deprecated Include Files  ',' 2015-11-30 2006-12-17 linking new to commands ',
 'FunDeprecated  ADFun Object Deprecated Member Functions  ',' syntax purpose dependent 2007-08-07 order 2006-03-31 memory size 2006-04-03 taylor_size 2006-06-17 use_vecad 2006-04-08 size_taylor 2014-03-18 capacity_taylor ',
 'CompareChange  Comparison Changes During Zero Order Forward Mode  ',' adfun syntax deprecated 2015-01-20 purpose discussion ',
