@@ -1,6 +1,6 @@
-// $Id: print_for.cpp 3757 2015-11-30 12:03:07Z bradbell $
+// $Id: print_for.cpp 3788 2016-02-09 15:50:06Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -19,7 +19,7 @@ $$
 $section Print During Zero Order Forward Mode: Example and Test$$
 
 $code
-$verbatim%example/print_for.cpp%0%// BEGIN C++%// END C++%1%$$
+$srcfile%example/print_for.cpp%0%// BEGIN C++%// END C++%1%$$
 $$
 
 $end
