@@ -1,6 +1,6 @@
-// $Id: jacobian.cpp 3785 2016-02-08 12:53:06Z bradbell $
+// $Id: jacobian.cpp 3856 2016-12-21 05:51:22Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -50,6 +50,8 @@ bool jacobian(void)
 {	bool ok = true;
 	using CppAD::vector;
 	size_t i, j, k;
+	using CppAD::NearEqual;
+	double eps99 = 99.0 * std::numeric_limits<double>::epsilon();
 
 	size_t n = 4;
 	size_t m = 2;
@@ -71,12 +73,12 @@ bool jacobian(void)
 	// regular jacobian
 	vector<double> jac_g = fun_g.Jacobian(x);
 	for(k = 0; k < m *n; k++)
-		ok &= CppAD::NearEqual(jac_g[k], check[k], 1e-10, 1e-10);
+		ok &= NearEqual(jac_g[k], check[k], eps99, eps99);
 
 	// one argument sparse jacobian
 	jac_g = fun_g.SparseJacobian(x);
 	for(k = 0; k < m *n; k++)
-		ok &= CppAD::NearEqual(jac_g[k], check[k], 1e-10, 1e-10);
+		ok &= NearEqual(jac_g[k], check[k], eps99, eps99);
 
 	// sparse jacobian using bool vectors
 	CPPAD_TESTVECTOR(bool) p_b(m * n) , r_b(n * n);
@@ -86,7 +88,7 @@ bool jacobian(void)
 	p_b = fun_g.ForSparseJac(n, r_b);
 	jac_g = fun_g.SparseJacobian(x, p_b);
 	for(k = 0; k < m *n; k++)
-		ok &= CppAD::NearEqual(jac_g[k], check[k], 1e-10, 1e-10);
+		ok &= NearEqual(jac_g[k], check[k], eps99, eps99);
 
 	// sparse jacobian using vectors of sets
 	std::vector< std::set<size_t> > p_s(m) , r_s(n);
@@ -96,7 +98,7 @@ bool jacobian(void)
 	p_s = fun_g.ForSparseJac(n, r_s);
 	jac_g = fun_g.SparseJacobian(x, p_s);
 	for(k = 0; k < m *n; k++)
-		ok &= CppAD::NearEqual(jac_g[k], check[k], 1e-10, 1e-10);
+		ok &= NearEqual(jac_g[k], check[k], eps99, eps99);
 
 	return ok;
 }
