@@ -1,6 +1,6 @@
-// $Id: test_vector.cpp 3785 2016-02-08 12:53:06Z bradbell $
+// $Id: test_vector.cpp 3856 2016-12-21 05:51:22Z bradbell $
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-16 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
@@ -20,6 +20,7 @@ bool test_vector(void)
 {	bool ok = true;
 	using CppAD::AD;
 	using CppAD::NearEqual;
+	double eps99 = 99.0 * std::numeric_limits<double>::epsilon();
 
 	// domain space vector
 	size_t n  = 1;
@@ -45,21 +46,21 @@ bool test_vector(void)
 	CppAD::ADFun<double> f(x, y);
 
 	// check value
-	ok &= NearEqual(y[0] , 2. * x0 + 10,  1e-10 , 1e-10);
+	ok &= NearEqual(y[0] , 2. * x0 + 10, eps99, eps99);
 
 	// forward computation of partials w.r.t. x[0]
 	CPPAD_TEST_VECTOR< double > dx(n);
 	CPPAD_TEST_VECTOR< double > dy(m);
 	dx[0] = 1.;
 	dy    = f.Forward(1, dx);
-	ok   &= NearEqual(dy[0], 2., 1e-10, 1e-10);
+	ok   &= NearEqual(dy[0], 2., eps99, eps99);
 
 	// reverse computation of derivative of y[0]
 	CPPAD_TEST_VECTOR< double >  w(m);
 	CPPAD_TEST_VECTOR< double > dw(n);
 	w[0]  = 1.;
 	dw    = f.Reverse(1, w);
-	ok   &= NearEqual(dw[0], 2., 1e-10, 1e-10);
+	ok   &= NearEqual(dw[0], 2., eps99, eps99);
 
 	// use a VecAD<Base>::reference object with addition
 	CppAD::VecAD<double> v(1);
